==> zio-aws-apigatewaymanagementapi_2.12-5.17.115.1-sources.jar: zio/aws/apigatewaymanagementapi/model/DeleteConnectionRequest.scala <==
package zio.aws.apigatewaymanagementapi.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.apigatewaymanagementapi.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DeleteConnectionRequest(connectionId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewaymanagementapi.model.DeleteConnectionRequest = {
    import DeleteConnectionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewaymanagementapi.model.DeleteConnectionRequest
      .builder()
      .connectionId(__string.unwrap(connectionId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewaymanagementapi.model.DeleteConnectionRequest.ReadOnly =
    zio.aws.apigatewaymanagementapi.model.DeleteConnectionRequest
      .wrap(buildAwsValue())
}
object DeleteConnectionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewaymanagementapi.model.DeleteConnectionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.apigatewaymanagementapi.model.DeleteConnectionRequest =
      zio.aws.apigatewaymanagementapi.model
        .DeleteConnectionRequest(connectionId)
    def connectionId: __string
    def getConnectionId: ZIO[Any, Nothing, __string] = ZIO.succeed(connectionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewaymanagementapi.model.DeleteConnectionRequest
  ) extends zio.aws.apigatewaymanagementapi.model.DeleteConnectionRequest.ReadOnly {
    override val connectionId: __string =
      zio.aws.apigatewaymanagementapi.model.primitives
        .__string(impl.connectionId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewaymanagementapi.model.DeleteConnectionRequest
  ): zio.aws.apigatewaymanagementapi.model.DeleteConnectionRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigatewaymanagementapi_2.12-5.20.22.2-sources.jar: zio/aws/apigatewaymanagementapi/model/DeleteConnectionRequest.scala <==
package zio.aws.apigatewaymanagementapi.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.apigatewaymanagementapi.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DeleteConnectionRequest(connectionId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewaymanagementapi.model.DeleteConnectionRequest = {
    import DeleteConnectionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewaymanagementapi.model.DeleteConnectionRequest
      .builder()
      .connectionId(connectionId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewaymanagementapi.model.DeleteConnectionRequest.ReadOnly =
    zio.aws.apigatewaymanagementapi.model.DeleteConnectionRequest
      .wrap(buildAwsValue())
}
object DeleteConnectionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewaymanagementapi.model.DeleteConnectionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.apigatewaymanagementapi.model.DeleteConnectionRequest =
      zio.aws.apigatewaymanagementapi.model
        .DeleteConnectionRequest(connectionId)
    def connectionId: __string
    def getConnectionId: ZIO[Any, Nothing, __string] = ZIO.succeed(connectionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewaymanagementapi.model.DeleteConnectionRequest
  ) extends zio.aws.apigatewaymanagementapi.model.DeleteConnectionRequest.ReadOnly {
    override val connectionId: __string = impl.connectionId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewaymanagementapi.model.DeleteConnectionRequest
  ): zio.aws.apigatewaymanagementapi.model.DeleteConnectionRequest.ReadOnly =
    new Wrapper(impl)
}
